Function unmap
Source pub(super) unsafe fn unmap(ptr: *mut u8, len: usize, _align: usize)
Available on Unix and crate feature pool and non-miri only.
Releases a mapping returned by map.
Safety
ptr, len, and align must describe exactly one prior map
result, with no outstanding references into the range.